==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/messagewidgets.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>EditWidgetClass</name>
    <message>
        <source>Send</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MessageWidgets</name>
    <message>
        <source>Messages</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <source>Tab Window %1</source>
        <translation>Tab Fenster %1</translation>
    </message>
    <message>
        <source>Main Tab Window</source>
        <translation>Haupt Tab Fenster</translation>
    </message>
    <message>
        <source>Message Widgets Manager</source>
        <translation>Nachrichten Widgets Manager</translation>
    </message>
    <message>
        <source>Allows other modules to use standard widgets for messaging</source>
        <translation>Erlaubt anderen Modulen Standard widget für Nachrichtenübertragung zu nutzen</translation>
    </message>
    <message>
        <source>Quote selected text</source>
        <translation></translation>
    </message>
    <message>
        <source>Tab Window</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable tab windows</source>
        <translation></translation>
    </message>
    <message>
        <source>Show status changes in chat windows</source>
        <translation></translation>
    </message>
    <message>
        <source>Auto resize input field</source>
        <translation></translation>
    </message>
    <message>
        <source>Show contact information in chat windows</source>
        <translation></translation>
    </message>
    <message>
        <source>Save status messages to history</source>
        <translation></translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation></translation>
    </message>
    <message>
        <source>Close tab</source>
        <translation></translation>
    </message>
    <message>
        <source>Detach tab to separate window</source>
        <translation></translation>
    </message>
    <message>
        <source>Next tab</source>
        <translation></translation>
    </message>
    <message>
        <source>Previous tab</source>
        <translation></translation>
    </message>
    <message>
        <source>Set tabs closable</source>
        <translation></translation>
    </message>
    <message>
        <source>Show tabs at bottom</source>
        <translation></translation>
    </message>
    <message>
        <source>Rename tab window</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete tab window</source>
        <translation></translation>
    </message>
    <message>
        <source>Use as default tab window</source>
        <translation></translation>
    </message>
    <message>
        <source>Alt+%1</source>
        <comment>Show tab</comment>
        <translation></translation>
    </message>
    <message>
        <source>Message windows</source>
        <translation></translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation></translation>
    </message>
    <message>
        <source>Send message</source>
        <translation></translation>
    </message>
    <message>
        <source>Return</source>
        <comment>Send message</comment>
        <translation></translation>
    </message>
    <message>
        <source>Message window</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation></translation>
    </message>
    <message>
        <source>Edit next message</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <comment>Edit next message</comment>
        <translation></translation>
    </message>
    <message>
        <source>Edit previous message</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <comment>Edit previous message</comment>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <comment>Close tab</comment>
        <translation></translation>
    </message>
    <message>
        <source>Show tabs indices</source>
        <translation></translation>
    </message>
    <message>
        <source>Close tab window</source>
        <translation></translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close tab window</comment>
        <translation></translation>
    </message>
    <message>
        <source>Close message window</source>
        <translation></translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close message window</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>MessageWindow</name>
    <message>
        <source>Next - %1</source>
        <translation>Nächste - %1</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>MessageWindowClass</name>
    <message>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>An:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Betreff:</translation>
    </message>
    <message>
        <source>Reply</source>
        <translation>Antworten</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
</context>
<context>
    <name>MessengerOptionsClass</name>
    <message>
        <source>Minimum input field lines:</source>
        <translation>Minimale Anzahl Eingabefeld Zeilen:</translation>
    </message>
    <message>
        <source>Clean chat windows after closing in </source>
        <translation></translation>
    </message>
    <message>
        <source> minutes</source>
        <translation></translation>
    </message>
    <message>
        <source>(0 - do not clean)</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ReceiversWidget</name>
    <message>
        <source>Receivers</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Not in Roster</source>
        <translation>Nicht im Roster</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Agents</source>
        <translation>Agenten</translation>
    </message>
    <message>
        <source>Blank group</source>
        <translation>Leere Gruppe</translation>
    </message>
    <message>
        <source>My Resources</source>
        <translation>Meine Resourcen</translation>
    </message>
    <message>
        <source>Add receiver</source>
        <translation>Empfänger hinzufügen</translation>
    </message>
    <message>
        <source>Enter valid contact jid:</source>
        <translation>Gültige Kontakt JID eingeben:</translation>
    </message>
</context>
<context>
    <name>ReceiversWidgetClass</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
</context>
<context>
    <name>TabWindow</name>
    <message>
        <source>Close Tab</source>
        <translation>Tab Schließen</translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation>Nächster Tab</translation>
    </message>
    <message>
        <source>Prev. Tab</source>
        <translation>Vorheriger Tab</translation>
    </message>
    <message>
        <source>Tabs Closable</source>
        <translation>Schließbare Tabs</translation>
    </message>
    <message>
        <source>Detach to Separate Window</source>
        <translation>In speparates Fenster abdocken</translation>
    </message>
    <message>
        <source>Join to</source>
        <translation>Anschließen an</translation>
    </message>
    <message>
        <source>New Tab Window</source>
        <translation>Neues Tab Fenster</translation>
    </message>
    <message>
        <source>Use as Default Tab Window</source>
        <translation>Benutze als Standard Tab Fenster</translation>
    </message>
    <message>
        <source>Rename Tab Window</source>
        <translation>Tab Fenster umbenennen</translation>
    </message>
    <message>
        <source>Delete Tab Window</source>
        <translation>Lösche Tab Fenster</translation>
    </message>
    <message>
        <source>Tab window name:</source>
        <translation>Tab Fenster Name:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this tab window?</source>
        <translation>Sind Sie sicher, dass Sie dieses Tab Fenster löschen wollen?</translation>
    </message>
    <message>
        <source>Show Tabs at Bottom of the Window</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Tabs Indices</source>
        <translation></translation>
    </message>
    <message>
        <source>Close Tab Window</source>
        <translation></translation>
    </message>
    <message>
        <source>%1) %2</source>
        <comment>First is tab index, second is tab name</comment>
        <translation></translation>
    </message>
    <message>
        <source>Remove all tabs on window close</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TabWindowClass</name>
    <message>
        <source>Tab 1</source>
        <translation>Tab 1</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/de/messagewidgets.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ChatWindow</name>
    <message>
        <source>Quote selected text</source>
        <translation>Selektierten Text zitieren</translation>
    </message>
</context>
<context>
    <name>EditWidget</name>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
</context>
<context>
    <name>MessageWidgets</name>
    <message>
        <source>Messages</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <source>Tab Window %1</source>
        <translation>Tab Fenster %1</translation>
    </message>
    <message>
        <source>Main Tab Window</source>
        <translation>Haupt Tab Fenster</translation>
    </message>
    <message>
        <source>Message Widgets Manager</source>
        <translation>Nachrichten Widgets Manager</translation>
    </message>
    <message>
        <source>Allows other modules to use standard widgets for messaging</source>
        <translation>Erlaubt anderen Modulen Standard widget für Nachrichtenübertragung zu nutzen</translation>
    </message>
    <message>
        <source>Quote selected text</source>
        <translation>Selektierten text zitieren</translation>
    </message>
    <message>
        <source>Tab Window</source>
        <translation>Tab Fenster</translation>
    </message>
    <message>
        <source>Enable tab windows</source>
        <translation>Tab Fenster aktivieren</translation>
    </message>
    <message>
        <source>Show status changes in chat windows</source>
        <translation>Status Änderungen in Chat Fenstern zeigen</translation>
    </message>
    <message>
        <source>Auto resize input field</source>
        <translation>Größe des Eingabefeldes automatisch anpassen</translation>
    </message>
    <message>
        <source>Show contact information in chat windows</source>
        <translation>Kontakt informationen in Chat Fenstern zeigen</translation>
    </message>
    <message>
        <source>Save status messages to history</source>
        <translation>Status Meldungen in der Historie speichern</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation>Tab Fenster</translation>
    </message>
    <message>
        <source>Close tab</source>
        <translation>Tab Fenster schließen</translation>
    </message>
    <message>
        <source>Detach tab to separate window</source>
        <translation>Tab in eigenes Fenster abtrennen</translation>
    </message>
    <message>
        <source>Next tab</source>
        <translation>Nächster Tab</translation>
    </message>
    <message>
        <source>Previous tab</source>
        <translation>Vorheriger Tab</translation>
    </message>
    <message>
        <source>Set tabs closable</source>
        <translation>Setze Tabs schliesbar</translation>
    </message>
    <message>
        <source>Show tabs at bottom</source>
        <translation>Tabs unten anzeigen</translation>
    </message>
    <message>
        <source>Rename tab window</source>
        <translation>Tab Fenster umbenennen</translation>
    </message>
    <message>
        <source>Delete tab window</source>
        <translation>Tab Fenster löschen</translation>
    </message>
    <message>
        <source>Use as default tab window</source>
        <translation>Als Standard Tab Fenster verwenden</translation>
    </message>
    <message>
        <source>Alt+%1</source>
        <comment>Show tab</comment>
        <translation>Alt+%1</translation>
    </message>
    <message>
        <source>Message windows</source>
        <translation>Nachrichten Fenster</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Chat Fenster</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation>Nachricht senden</translation>
    </message>
    <message>
        <source>Return</source>
        <comment>Send message</comment>
        <translation>Return</translation>
    </message>
    <message>
        <source>Message window</source>
        <translation>Nachrichten Fenster</translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation>Strg+Return</translation>
    </message>
    <message>
        <source>Edit next message</source>
        <translation>Nächste Nachricht bearbeiten</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <comment>Edit next message</comment>
        <translation>Strg+Down</translation>
    </message>
    <message>
        <source>Edit previous message</source>
        <translation>Vorherige Nachricht bearbeiten</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <comment>Edit previous message</comment>
        <translation>Strg+Up</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <comment>Close tab</comment>
        <translation>Strg+W</translation>
    </message>
    <message>
        <source>Show tabs indices</source>
        <translation>Zeige Tab Indizies</translation>
    </message>
    <message>
        <source>Close tab window</source>
        <translation>Schließe Tab Fenster</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close tab window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Close message window</source>
        <translation>Schließe Nachrichten Fenster</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close message window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Send mail</source>
        <translation>Sende Nachricht</translation>
    </message>
    <message>
        <source>Open link</source>
        <translation>Öffne Link</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiere Adresse</translation>
    </message>
    <message>
        <source>Search on Google &apos;%1&apos;</source>
        <translation>&apos;%1&apos; bei Google suchen</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Andere Tabs schließen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+W</source>
        <comment>Close other tabs</comment>
        <translation>Strg+Shift+W</translation>
    </message>
</context>
<context>
    <name>MessageWindow</name>
    <message>
        <source>Next - %1</source>
        <translation>Nächste - %1</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>MessageWindowClass</name>
    <message>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>An:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Betreff:</translation>
    </message>
    <message>
        <source>Reply</source>
        <translation>Antworten</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
</context>
<context>
    <name>MessengerOptionsClass</name>
    <message>
        <source>Minimum input field lines:</source>
        <translation>Minimale Anzahl Eingabefeld Zeilen:</translation>
    </message>
    <message>
        <source>Clean chat windows after closing in </source>
        <translation>Chat Fenster nach dem Schließen leeren in </translation>
    </message>
    <message>
        <source> minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>(0 - do not clean)</source>
        <translation>(0 - nicht leeren)</translation>
    </message>
</context>
<context>
    <name>ReceiversWidget</name>
    <message>
        <source>Receivers</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Not in Roster</source>
        <translation>Nicht im Roster</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Agents</source>
        <translation>Agenten</translation>
    </message>
    <message>
        <source>My Resources</source>
        <translation>Meine Resourcen</translation>
    </message>
    <message>
        <source>Add receiver</source>
        <translation>Empfänger hinzufügen</translation>
    </message>
    <message>
        <source>Enter valid contact jid:</source>
        <translation>Gültige Kontakt JID eingeben:</translation>
    </message>
    <message>
        <source>Without Groups</source>
        <translation>Ohne Gruppen</translation>
    </message>
</context>
<context>
    <name>ReceiversWidgetClass</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>All Online</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabWindow</name>
    <message>
        <source>Close Tab</source>
        <translation>Tab Schließen</translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation>Nächster Tab</translation>
    </message>
    <message>
        <source>Prev. Tab</source>
        <translation>Vorheriger Tab</translation>
    </message>
    <message>
        <source>Tabs Closable</source>
        <translation>Schließbare Tabs</translation>
    </message>
    <message>
        <source>Detach to Separate Window</source>
        <translation>In speparates Fenster abdocken</translation>
    </message>
    <message>
        <source>Join to</source>
        <translation>Anschließen an</translation>
    </message>
    <message>
        <source>New Tab Window</source>
        <translation>Neues Tab Fenster</translation>
    </message>
    <message>
        <source>Use as Default Tab Window</source>
        <translation>Benutze als Standard Tab Fenster</translation>
    </message>
    <message>
        <source>Rename Tab Window</source>
        <translation>Tab Fenster umbenennen</translation>
    </message>
    <message>
        <source>Delete Tab Window</source>
        <translation>Lösche Tab Fenster</translation>
    </message>
    <message>
        <source>Tab window name:</source>
        <translation>Tab Fenster Name:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this tab window?</source>
        <translation>Sind Sie sicher, dass Sie dieses Tab Fenster löschen wollen?</translation>
    </message>
    <message>
        <source>Show Tabs at Bottom of the Window</source>
        <translation>Zeige Tabs am unteren Fensterrand</translation>
    </message>
    <message>
        <source>Show Tabs Indices</source>
        <translation>Zeige Tab Indizes</translation>
    </message>
    <message>
        <source>Close Tab Window</source>
        <translation>Schließe Tab Fenster</translation>
    </message>
    <message>
        <source>Remove all tabs on window close</source>
        <translation>Entferne alle Tabs wenn das Fenster geschlossen wird</translation>
    </message>
    <message>
        <source>%1) %2</source>
        <translation>%1) %2</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>Andere Tabs schließen</translation>
    </message>
</context>
<context>
    <name>TabWindowClass</name>
    <message>
        <source>Tab 1</source>
        <translation>Tab 1</translation>
    </message>
</context>
</TS>
